@@ -20,7 +20,11 @@ lpc.curve.length <- function(lpcsl,or.pi,branch=0,total.subdivisions=1e4,min.sub
       from <- c(0,cur.or.pi)
       for (i in 1:length(cur.or.pi.order)) {        
         subdivisions <- max(min.subdivisions,ceiling(total.subdivisions*(cur.or.pi[i]-from[i])/(lpcsl[[cur.branch+1]]$range[2]-lpcsl[[cur.branch+1]]$range[1])))
-        length.between.points[i] <- integrate(gradnorm,lower=from[i],upper=cur.or.pi[i],subdivisions=subdivisions,sps=lpcsl[[cur.branch+1]]$splinefun)$value
+        if(from[i]==cur.or.pi[i]){
+                length.between.points[i] <-0
+        } else {    
+            length.between.points[i] <- integrate(gradnorm,lower=from[i],upper=cur.or.pi[i],subdivisions=subdivisions,sps=lpcsl[[cur.branch+1]]$splinefun)$value
+        }
       }
       total.length <- cumsum(length.between.points)
       result[branch==cur.branch][cur.or.pi.order] <- total.length
